### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.11.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.10.3...v0.11.0)

> 9 February 2022

- Update to latest contracts (wasn't commited before somehow) [`#60`](https://github.com/nevermined-io/contracts-lib-py/pull/60)
- Added support for celo and matic. [`#59`](https://github.com/nevermined-io/contracts-lib-py/pull/59)
- fixed test [`524c06d`](https://github.com/nevermined-io/contracts-lib-py/commit/524c06d662f517d8a74f8bcd42224c651e548df5)
- Adding v0.10.3 Changelog updates [`644747a`](https://github.com/nevermined-io/contracts-lib-py/commit/644747a67ba0119d30451d07334299483c6ee6c6)
- fix test [`0ed4a75`](https://github.com/nevermined-io/contracts-lib-py/commit/0ed4a753d45f25a62b75c3985b94bfc5a280cf55)

#### [v0.10.3](https://github.com/nevermined-io/contracts-lib-py/compare/v0.10.2...v0.10.3)

> 8 February 2022

- Gas estimation problem [`#58`](https://github.com/nevermined-io/contracts-lib-py/pull/58)
- Adding v0.10.2 Changelog updates [`537c619`](https://github.com/nevermined-io/contracts-lib-py/commit/537c61912754404a58cb6afdf14b4b6f750d1ff3)
- disable baklava [`5fbb8f7`](https://github.com/nevermined-io/contracts-lib-py/commit/5fbb8f71dfdab732e7fca33eb53eef9efa3209d3)
- use fixed gas [`d6ced49`](https://github.com/nevermined-io/contracts-lib-py/commit/d6ced49956827d3bd52e3cf4e4add1ed8c85c7f4)

#### [v0.10.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.10.1...v0.10.2)

> 28 January 2022

- contracts version [`#57`](https://github.com/nevermined-io/contracts-lib-py/pull/57)
- Update web3 [`#56`](https://github.com/nevermined-io/contracts-lib-py/pull/56)
- check if the network supports eip 1559 [`147d481`](https://github.com/nevermined-io/contracts-lib-py/commit/147d4814616dca0ec1e3bfe7c2b4216d4298c40c)
- works with openethereum [`45aa81d`](https://github.com/nevermined-io/contracts-lib-py/commit/45aa81dad32ae547006a7637d43b92fc11a924f4)
- Adding v0.10.1 Changelog updates [`b14b019`](https://github.com/nevermined-io/contracts-lib-py/commit/b14b019037eeadd3c8cd42fc8093b1359725b0c4)

#### [v0.10.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.10.0...v0.10.1)

> 21 December 2021

- Fix gasPrice when sending transactions [`#54`](https://github.com/nevermined-io/contracts-lib-py/pull/54)
- Adding v0.10.0 Changelog updates [`2b4a26d`](https://github.com/nevermined-io/contracts-lib-py/commit/2b4a26dc31c0341bb47cd71c2cd80220458c03d6)

#### [v0.10.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.9.2...v0.10.0)

> 10 December 2021

- Support for contracts 1.3.0 in mumbai [`#51`](https://github.com/nevermined-io/contracts-lib-py/pull/51)
- Adding v0.9.2 Changelog updates [`cf50c23`](https://github.com/nevermined-io/contracts-lib-py/commit/cf50c231044e694b2f9e87b5349c116ff3fca3f9)

#### [v0.9.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.9.1...v0.9.2)

> 2 December 2021

- Added support for contracts 1.3.0 [`#50`](https://github.com/nevermined-io/contracts-lib-py/pull/50)
- Adding v0.9.1 Changelog updates [`07b4a48`](https://github.com/nevermined-io/contracts-lib-py/commit/07b4a486bd4a32b179c1a5656b93e6c85a3eb53c)

#### [v0.9.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.9.0...v0.9.1)

> 29 November 2021

- Fix optional args order [`#49`](https://github.com/nevermined-io/contracts-lib-py/pull/49)
- Adding v0.9.0 Changelog updates [`1a8a4f2`](https://github.com/nevermined-io/contracts-lib-py/commit/1a8a4f224daee58c5c25c769c14aadbe1c4d7f5a)

#### [v0.9.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.8.0...v0.9.0)

> 26 November 2021

- Integration of contracts v1.2.2 [`#47`](https://github.com/nevermined-io/contracts-lib-py/pull/47)
- Tmp/check ci [`#48`](https://github.com/nevermined-io/contracts-lib-py/pull/48)
- NFTUpgreadable integration [`5914ec8`](https://github.com/nevermined-io/contracts-lib-py/commit/5914ec8674f58d70b3f9d97e5c7ade228595af2f)
- Adding v0.8.0 Changelog updates [`effc7f0`](https://github.com/nevermined-io/contracts-lib-py/commit/effc7f067774bbc7943f5abb56c348763aca8388)
- latest flag and comments [`b21dcf9`](https://github.com/nevermined-io/contracts-lib-py/commit/b21dcf9179e1d4f65a20773e335b3c8dfc511f12)

#### [v0.8.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.20...v0.8.0)

> 28 October 2021

- Cleanup, fixing `generate_id` [`#46`](https://github.com/nevermined-io/contracts-lib-py/pull/46)
- Remove the use of the filtering api when getting event data [`#45`](https://github.com/nevermined-io/contracts-lib-py/pull/45)
- Updated CI to also test against polygon-localnet [`#44`](https://github.com/nevermined-io/contracts-lib-py/pull/44)
- Replaced filtering api with getLogs when fetching event data [`e7bd8a3`](https://github.com/nevermined-io/contracts-lib-py/commit/e7bd8a339d13fdf2f07fd9fe923776ccfc4bc6be)
- Adding v0.7.20 Changelog updates [`88aed10`](https://github.com/nevermined-io/contracts-lib-py/commit/88aed1062fc47b19edf99079de06d0250c9c069c)
- something wrong with solidityKeccak [`625407b`](https://github.com/nevermined-io/contracts-lib-py/commit/625407b8c5cb84668ff643d55065155a2d94691f)

#### [v0.7.20](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.19...v0.7.20)

> 27 October 2021

- Fix some issues with the python filter api since its not supported on polygon [`#43`](https://github.com/nevermined-io/contracts-lib-py/pull/43)
- Fix some issues with the python filter api since its not supported on [`04c71ef`](https://github.com/nevermined-io/contracts-lib-py/commit/04c71efb5efcb79f4a7092cc334a405ac7d5b507)
- Adding v0.7.19 Changelog updates [`1eabca3`](https://github.com/nevermined-io/contracts-lib-py/commit/1eabca384859a92943d8720ee56f040d3a5a281a)
- bumped version [`e05c9f0`](https://github.com/nevermined-io/contracts-lib-py/commit/e05c9f0ccc7a0b750b7f96d8df8192a303e0b212)

#### [v0.7.19](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.18...v0.7.19)

> 26 October 2021

- Fixes a bug on the keeper initialization [`#42`](https://github.com/nevermined-io/contracts-lib-py/pull/42)
- Adding v0.7.18 Changelog updates [`df6cb33`](https://github.com/nevermined-io/contracts-lib-py/commit/df6cb3309f6d98b7eaaf2ee15b72625936eae3ed)

#### [v0.7.18](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.17...v0.7.18)

> 26 October 2021

- Small fix so the keeper works with polygon [`#41`](https://github.com/nevermined-io/contracts-lib-py/pull/41)
- Fix/aurora mainnet [`#39`](https://github.com/nevermined-io/contracts-lib-py/pull/39)
- Adding v0.7.17 Changelog updates [`0dbf384`](https://github.com/nevermined-io/contracts-lib-py/commit/0dbf38432bce0068fc12bc4a3f292bdac3e8f0b6)
- update changelog [`e3d7435`](https://github.com/nevermined-io/contracts-lib-py/commit/e3d74351d6bd2323eced5c4d21cb16507ce3d9f0)
- update changelog [`8b3a252`](https://github.com/nevermined-io/contracts-lib-py/commit/8b3a25285eb964b8bba5e803e3f011ff8ba8511c)

#### [v0.7.17](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.16...v0.7.17)

> 8 October 2021

- Make AccessProof contracts optional [`#40`](https://github.com/nevermined-io/contracts-lib-py/pull/40)
- bump version [`37b9f3b`](https://github.com/nevermined-io/contracts-lib-py/commit/37b9f3b83a087896d4681a0b192ab15dda96158d)

#### [v0.7.16](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.15...v0.7.16)

> 1 October 2021

- fix aurora mainnet name [`#38`](https://github.com/nevermined-io/contracts-lib-py/pull/38)
- update changelog [`e3d7435`](https://github.com/nevermined-io/contracts-lib-py/commit/e3d74351d6bd2323eced5c4d21cb16507ce3d9f0)

#### [v0.7.15](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.14...v0.7.15)

> 30 September 2021

- Feature/contracts 1.1.8 [`#37`](https://github.com/nevermined-io/contracts-lib-py/pull/37)
- Adding wrappers for data transfer contracts [`#35`](https://github.com/nevermined-io/contracts-lib-py/pull/35)
- support aurora networks [`#36`](https://github.com/nevermined-io/contracts-lib-py/pull/36)
- adding contract wrappers [`ae27b4b`](https://github.com/nevermined-io/contracts-lib-py/commit/ae27b4b99e83b329d06215822a744002f70e5a47)
- get correct temmplate [`13a134e`](https://github.com/nevermined-io/contracts-lib-py/commit/13a134e9a52657acd5636099ce386492a6f238d4)
- Upgrade versions [`fd504fb`](https://github.com/nevermined-io/contracts-lib-py/commit/fd504fb7e13146158a7165fd1247d13aebd411af)

#### [v0.7.14](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.13...v0.7.14)

> 22 September 2021

- white spaces [`0a45577`](https://github.com/nevermined-io/contracts-lib-py/commit/0a45577120ba6f288013ac07fda705f4ec68c63c)
- fix syntax [`4c19e87`](https://github.com/nevermined-io/contracts-lib-py/commit/4c19e871588367c28924c03077f40de0dd99a7a5)

#### [v0.7.13](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.12...v0.7.13)

> 21 September 2021

- Adding v0.7.12 Changelog updates [`10c4254`](https://github.com/nevermined-io/contracts-lib-py/commit/10c4254837508f2b0dc59db36b20091ec3b6a740)
- support aurora networks [`d2e9aa9`](https://github.com/nevermined-io/contracts-lib-py/commit/d2e9aa9ac3af9d68173d8d451637ac952fbe48d3)
- fix versions [`51b6bf6`](https://github.com/nevermined-io/contracts-lib-py/commit/51b6bf63a89d74479a170eabeab799c8bfeef457)

#### [v0.7.12](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.11...v0.7.12)

> 9 September 2021

- Add compatibility with polygon [`#33`](https://github.com/nevermined-io/contracts-lib-py/pull/33)
- Add chainId to the transaction [`57a8302`](https://github.com/nevermined-io/contracts-lib-py/commit/57a830215419b2c58c38ca26832366cae558d409)
- Adding v0.7.11 Changelog updates [`d1c8dc2`](https://github.com/nevermined-io/contracts-lib-py/commit/d1c8dc20fa6db58e3b80fa2e0959c3c508131c60)
- bump version [`1f3cd50`](https://github.com/nevermined-io/contracts-lib-py/commit/1f3cd503b72192264eafcd64afc980160096c8ca)

#### [v0.7.11](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.10...v0.7.11)

> 6 September 2021

- Fix/nft transfer condition [`#32`](https://github.com/nevermined-io/contracts-lib-py/pull/32)
- Adding v0.7.10 Changelog updates [`87b9665`](https://github.com/nevermined-io/contracts-lib-py/commit/87b9665a5129dc2009c4843643f28f2285d685d2)
- Add _nftHolder param to transferNFTcondition [`251c468`](https://github.com/nevermined-io/contracts-lib-py/commit/251c468acfdc7367645d7f10c4c9de3e2fdec10c)
- bump version [`987e1e0`](https://github.com/nevermined-io/contracts-lib-py/commit/987e1e0638100a6efcbfdbb32c3625159397d7e6)

#### [v0.7.10](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.9...v0.7.10)

> 3 September 2021

- Load the correct artifacts for different networks. [`#31`](https://github.com/nevermined-io/contracts-lib-py/pull/31)
- Using contracts `v1.1.4` [`#30`](https://github.com/nevermined-io/contracts-lib-py/pull/30)
- Fix tests [`673164b`](https://github.com/nevermined-io/contracts-lib-py/commit/673164ba01f0a02a4fd88535c1e11f8a78a30898)
- Added infura token to github actions [`9eb8188`](https://github.com/nevermined-io/contracts-lib-py/commit/9eb8188ad7879e0b565ac78d4d089725fee65df0)
- Fix failing test [`32cbcf8`](https://github.com/nevermined-io/contracts-lib-py/commit/32cbcf8ca7eafa7c6bc15e19596c4700e29ef30b)

#### [v0.7.9](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.8...v0.7.9)

> 24 August 2021

- Using contracts `v1.1.4` [`525326a`](https://github.com/nevermined-io/contracts-lib-py/commit/525326a1c5713a83e6b12ded234460e6a49364b0)
- Adding v0.7.8 Changelog updates [`a54b2d8`](https://github.com/nevermined-io/contracts-lib-py/commit/a54b2d851cf0184b40069ff8098862a16dcabafd)

#### [v0.7.8](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.7...v0.7.8)

> 13 August 2021

- using contracts v1.1.3 [`#29`](https://github.com/nevermined-io/contracts-lib-py/pull/29)
- Adding v0.7.7 Changelog updates [`2c0eb5f`](https://github.com/nevermined-io/contracts-lib-py/commit/2c0eb5f90086c8289cbd75b82ba98d2ee2de68c2)

#### [v0.7.7](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.6...v0.7.7)

> 11 August 2021

- Use version 1.1.2 of contracts [`#28`](https://github.com/nevermined-io/contracts-lib-py/pull/28)
- Adding v0.7.6 Changelog updates [`887fa02`](https://github.com/nevermined-io/contracts-lib-py/commit/887fa0235586ecec1189e497352db54fc3e274e4)

#### [v0.7.6](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.5...v0.7.6)

> 30 July 2021

- Support for nft721 [`#27`](https://github.com/nevermined-io/contracts-lib-py/pull/27)
- Added the ability to load contracts external to nevermined [`c9f346d`](https://github.com/nevermined-io/contracts-lib-py/commit/c9f346db68a0dc681bac7f8cdb266c433d72c43a)
- Fix CI [`1c732e9`](https://github.com/nevermined-io/contracts-lib-py/commit/1c732e9541da1b65e6c871ea023d76a12bc954f5)
- Adding v0.7.5 Changelog updates [`c140c16`](https://github.com/nevermined-io/contracts-lib-py/commit/c140c16dcb8e317526c75b3af18b576fb79312e9)

#### [v0.7.5](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.4...v0.7.5)

> 15 July 2021

- using contracts `v1.1.1` [`#26`](https://github.com/nevermined-io/contracts-lib-py/pull/26)
- Adding v0.7.4 Changelog updates [`2706730`](https://github.com/nevermined-io/contracts-lib-py/commit/2706730eb53f1aa31cd6aebeed7aab64ff45c072)

#### [v0.7.4](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.3...v0.7.4)

> 19 May 2021

- Integrating contracts v1 rc8 including the new way to register assets [`#25`](https://github.com/nevermined-io/contracts-lib-py/pull/25)
- Adding v0.7.3 Changelog updates [`5ddf9bd`](https://github.com/nevermined-io/contracts-lib-py/commit/5ddf9bd876dd792e58f69b08238c944d570b62a5)

#### [v0.7.3](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.2...v0.7.3)

> 13 May 2021

- Adding v0.7.2 Changelog updates [`bb86d58`](https://github.com/nevermined-io/contracts-lib-py/commit/bb86d5832faed0df57dbc1bde202d4d29b2a57ed)
- updating to last contracts version [`a96a5d9`](https://github.com/nevermined-io/contracts-lib-py/commit/a96a5d9a02a0a0797db66bd85e8a6b64e94505fb)

#### [v0.7.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.1...v0.7.2)

> 3 May 2021

- Added missing NFTLockCondition contract support [`#24`](https://github.com/nevermined-io/contracts-lib-py/pull/24)
- Adding v0.7.1 Changelog updates [`0e33a4a`](https://github.com/nevermined-io/contracts-lib-py/commit/0e33a4a62a04827bceec7489d6b417cbefc1ca46)

#### [v0.7.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.7.0...v0.7.1)

> 21 April 2021

- Fixing token address validation [`#23`](https://github.com/nevermined-io/contracts-lib-py/pull/23)
- Adding v0.7.0 Changelog updates [`d51e83f`](https://github.com/nevermined-io/contracts-lib-py/commit/d51e83f5560640a3b231fc31593388d6540e080a)

#### [v0.7.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.6.4...v0.7.0)

> 21 April 2021

- Adding `token_address` as new parameter to lock and escrow payment conditions [`#22`](https://github.com/nevermined-io/contracts-lib-py/pull/22)
- Adding v0.6.4 Changelog updates [`fa247a0`](https://github.com/nevermined-io/contracts-lib-py/commit/fa247a041e64208a72cecfd8c74d592b0e92a7d1)

#### [v0.6.4](https://github.com/nevermined-io/contracts-lib-py/compare/v0.6.3...v0.6.4)

> 15 April 2021

- Adding NFT Access condition [`#21`](https://github.com/nevermined-io/contracts-lib-py/pull/21)
- Adding v0.6.3 Changelog updates [`7ab24aa`](https://github.com/nevermined-io/contracts-lib-py/commit/7ab24aaab46b7277c4753cca1ec2cc424d2d978d)

#### [v0.6.3](https://github.com/nevermined-io/contracts-lib-py/compare/v0.6.2...v0.6.3)

> 12 April 2021

- Adapting to last contracts version rc2 [`#20`](https://github.com/nevermined-io/contracts-lib-py/pull/20)
- adding royalties and get did register functions to didregistry [`cfc3bc3`](https://github.com/nevermined-io/contracts-lib-py/commit/cfc3bc3318362f842c86fac9040fea5e0499a416)
- Adapting to last contracts version [`e9b6a79`](https://github.com/nevermined-io/contracts-lib-py/commit/e9b6a79f9f252e2ad9f094cc78967b4f70b2ae77)
- Adding v0.6.2 Changelog updates [`a059856`](https://github.com/nevermined-io/contracts-lib-py/commit/a059856bb0eaf9c69ca82e523aba01d38f5ef847)

#### [v0.6.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.6.1...v0.6.2)

> 30 March 2021

- Refactoring conditions and template name to adapt to contracts v1.0 [`#19`](https://github.com/nevermined-io/contracts-lib-py/pull/19)
- Adding v0.6.1 Changelog updates [`3faeffe`](https://github.com/nevermined-io/contracts-lib-py/commit/3faeffe922e1a32db5f176f8847b597a6dbbb6ec)

#### [v0.6.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.6.0...v0.6.1)

> 29 March 2021

- Adapting to contracts v1.0.0rc1 [`#18`](https://github.com/nevermined-io/contracts-lib-py/pull/18)
- Adding v0.6.0 Changelog updates [`9c6ce34`](https://github.com/nevermined-io/contracts-lib-py/commit/9c6ce34f0ef4e8ed499cf0d8f6440a725e0d9426)
- comming back to python 3.7 [`432b95b`](https://github.com/nevermined-io/contracts-lib-py/commit/432b95bd601ba300e4f526dc93bbe50c533ab804)
- comming back to python 3.7 [`a39e779`](https://github.com/nevermined-io/contracts-lib-py/commit/a39e779d14c0e2b35138a919a7de010309992e60)

#### [v0.6.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.5...v0.6.0)

> 18 March 2021

- Integrating with contracts v1.0.0 [`#17`](https://github.com/nevermined-io/contracts-lib-py/pull/17)
- Adding new conditions and templates implemented in contracts v1 [`fe89b94`](https://github.com/nevermined-io/contracts-lib-py/commit/fe89b9419319ab9d0ca8456acdca65988790e260)
- Adapting to new contract interfaces and condition names [`4c8171f`](https://github.com/nevermined-io/contracts-lib-py/commit/4c8171f009f7f4ec0b7fcec449a2a45c9a9a5304)
- Adding v0.5.5 Changelog updates [`dd8edb2`](https://github.com/nevermined-io/contracts-lib-py/commit/dd8edb207fb82cb739cab2ff9d29fafa92d2c508)

#### [v0.5.5](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.4...v0.5.5)

> 2 February 2021

- updating to last version of contracts `0.6.2` where the escrowReward requires a list of amounts and receivers [`#16`](https://github.com/nevermined-io/contracts-lib-py/pull/16)
- Adding v0.5.5 Changelog updates [`efab6f3`](https://github.com/nevermined-io/contracts-lib-py/commit/efab6f340d0b5b22bdb6e1aaddbb067951557524)
- Adapting to multiple addresses [`13e5a83`](https://github.com/nevermined-io/contracts-lib-py/commit/13e5a83860dfead0d8c5b396c34efdd7135dc731)
- fixing classifier [`30d9cf1`](https://github.com/nevermined-io/contracts-lib-py/commit/30d9cf1a0617bf408eb70c3f3fef6c8aa8d7d4e7)

#### [v0.5.4](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.3...v0.5.4)

> 8 January 2021

- Feature/upgrade contracts version [`#15`](https://github.com/nevermined-io/contracts-lib-py/pull/15)
- update changelog [`c0610b8`](https://github.com/nevermined-io/contracts-lib-py/commit/c0610b823b5b05ee4dba78c7b499b2a8480d9043)
- Upgrade contracts version [`52ae279`](https://github.com/nevermined-io/contracts-lib-py/commit/52ae2795ab059b482b52be20ba5297f4d8c90d02)

#### [v0.5.3](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.2...v0.5.3)

> 21 December 2020

- Add nft methods [`#14`](https://github.com/nevermined-io/contracts-lib-py/pull/14)
- update changelog [`000e1ee`](https://github.com/nevermined-io/contracts-lib-py/commit/000e1eed8c1ab2f6b86a551e4baf20d8559bcaf1)
- Bumpversion [`3b17e40`](https://github.com/nevermined-io/contracts-lib-py/commit/3b17e40f96bb8f081d3a0e6b50091f616bcd2c18)
- Update workflow [`694b17a`](https://github.com/nevermined-io/contracts-lib-py/commit/694b17a5a72dc9e3bfdf1b2a90c552e59e9fcc9d)

#### [v0.5.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.1...v0.5.2)

> 1 December 2020

- Feature/add new provenance methods [`#13`](https://github.com/nevermined-io/contracts-lib-py/pull/13)
- update changelog [`#12`](https://github.com/nevermined-io/contracts-lib-py/pull/12)
- Methods added [`c0f0189`](https://github.com/nevermined-io/contracts-lib-py/commit/c0f0189d8cd57f9e93bff4cda6becdd2b76dc677)
- Add missing methods [`cf7ee80`](https://github.com/nevermined-io/contracts-lib-py/commit/cf7ee80ae510a00fcddf09a9ebf10217a629f8d6)
- Comment rinkeby test until deployment of the new contracts [`8c5ae36`](https://github.com/nevermined-io/contracts-lib-py/commit/8c5ae366614f1f579590d5d84961c291f2451cdb)

#### [v0.5.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.5.0...v0.5.1)

> 10 November 2020

- Make dispenser and token contracts optional [`#10`](https://github.com/nevermined-io/contracts-lib-py/pull/10)
- Make NeverminedToken and Dispenser contract optional [`baa2169`](https://github.com/nevermined-io/contracts-lib-py/commit/baa216958fa2fa5e9c77ac54ed9fce073c70854b)
- fectch rinkeby artifacts before running the tests [`15f49df`](https://github.com/nevermined-io/contracts-lib-py/commit/15f49dfa98dcd26e1b01b33c5566907ffde336ec)
- bump version to 0.5.1 [`167576c`](https://github.com/nevermined-io/contracts-lib-py/commit/167576c5160832c068cdd6d7f164a30be39ff96e)

#### [v0.5.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.4.0...v0.5.0)

> 5 November 2020

- Adapting to new org [`66cd1f6`](https://github.com/nevermined-io/contracts-lib-py/commit/66cd1f67aa55c87af35b942bd56244e0a29a9c00)

#### [v0.4.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.2.4...v0.4.0)

> 13 August 2020

- Updating to contracts v0.4 [`#9`](https://github.com/nevermined-io/contracts-lib-py/pull/9)
- Bump version: 0.2.4 → 0.3.0 [`22c0025`](https://github.com/nevermined-io/contracts-lib-py/commit/22c00250a720118f2344a094ff0e8e3335e6a6db)
- adding docker login [`0bb2e6c`](https://github.com/nevermined-io/contracts-lib-py/commit/0bb2e6c99e168c5e4a0d6041b5e8105a5807fe3d)
- changing library version [`751ed08`](https://github.com/nevermined-io/contracts-lib-py/commit/751ed0853ce58c64d430ebcec9a3fcdf41631eca)

#### [v0.2.4](https://github.com/nevermined-io/contracts-lib-py/compare/v0.2.3...v0.2.4)

> 18 May 2020

- Change nonce calculation and chekc condition status twice [`#8`](https://github.com/nevermined-io/contracts-lib-py/pull/8)
- Bump version: 0.2.3 → 0.2.4 [`e327de6`](https://github.com/nevermined-io/contracts-lib-py/commit/e327de6861d797ae973e96cbe72e8fda158b039d)
- Remove 3.6 python workflow [`787b78d`](https://github.com/nevermined-io/contracts-lib-py/commit/787b78db7d838d836183fbdb60c075191e6509bc)

#### [v0.2.3](https://github.com/nevermined-io/contracts-lib-py/compare/v0.2.2...v0.2.3)

> 7 May 2020

- Remove concise_contract definition because is not necessary anymore [`#7`](https://github.com/nevermined-io/contracts-lib-py/pull/7)
- Bump version: 0.2.2 → 0.2.3 [`bf6e5e2`](https://github.com/nevermined-io/contracts-lib-py/commit/bf6e5e26375fc0bd5ce47d6046e01221a9e9ca5d)
- Update Changelog [`09fa84d`](https://github.com/nevermined-io/contracts-lib-py/commit/09fa84d06cf77e15e430fe1ba4a11acf9a9d6bc3)

#### [v0.2.2](https://github.com/nevermined-io/contracts-lib-py/compare/v0.2.1...v0.2.2)

> 6 May 2020

- Upgrade some deprecated methods [`#6`](https://github.com/nevermined-io/contracts-lib-py/pull/6)
- Upgrade some deprecated methods2 [`12b414d`](https://github.com/nevermined-io/contracts-lib-py/commit/12b414de2109bed8d351cf25a8ee1b7e60a1d909)
- Bump version: 0.2.1 → 0.2.2 [`f09507f`](https://github.com/nevermined-io/contracts-lib-py/commit/f09507fb6c99070fb9ab1ac666f690a790eec1eb)
- Update Changelog [`dc87939`](https://github.com/nevermined-io/contracts-lib-py/commit/dc879398cc98c124f2a51271e6c2d5bb4a7c7abc)

#### [v0.2.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.2.0...v0.2.1)

> 5 May 2020

- Feature/upgrade web3py version [`#5`](https://github.com/nevermined-io/contracts-lib-py/pull/5)
- Update Changelog [`982b84a`](https://github.com/nevermined-io/contracts-lib-py/commit/982b84a58233b128cb559a359bf9998d13a1282d)
- Update library to work with web3py 5.9.0 [`c1bc59f`](https://github.com/nevermined-io/contracts-lib-py/commit/c1bc59fa72f3f061a36aa0e932e8e4e3995d09cf)
- Bump version: 0.2.0 → 0.2.1 [`d5aec20`](https://github.com/nevermined-io/contracts-lib-py/commit/d5aec201e967aa7e5b113c94cd8c36f8155eb1c8)

#### [v0.2.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.1.1...v0.2.0)

> 29 April 2020

- Update names [`#3`](https://github.com/nevermined-io/contracts-lib-py/pull/3)
- Bump version: 0.1.1 → 0.2.0 [`3bb84d8`](https://github.com/nevermined-io/contracts-lib-py/commit/3bb84d84dd01d38e4bb6d2f9b83f81a21c8c4ae0)
- Update command in workflow [`50af912`](https://github.com/nevermined-io/contracts-lib-py/commit/50af9120127054913b61e496b458d31ad70fecfe)
- Update keeper version2 [`2f4f8be`](https://github.com/nevermined-io/contracts-lib-py/commit/2f4f8be2b9797d8239675af71c9e495e89389352)

#### [v0.1.1](https://github.com/nevermined-io/contracts-lib-py/compare/v0.1.0...v0.1.1)

> 24 April 2020

- Feature/update licenses and templates [`#1`](https://github.com/nevermined-io/contracts-lib-py/pull/1)
- Update licenses and templates [`ebc3527`](https://github.com/nevermined-io/contracts-lib-py/commit/ebc3527a8c4d0040315194f47cea8d4b98863a0b)
- Bump version: 0.1.0 → 0.1.1 [`140660e`](https://github.com/nevermined-io/contracts-lib-py/commit/140660e8c8a4824e5e86bf2d1579d4e011c08a07)
- Update README.md [`252a79c`](https://github.com/nevermined-io/contracts-lib-py/commit/252a79cc92cc86f303a404b4b6d0d0855cc103e2)

#### [v0.1.0](https://github.com/nevermined-io/contracts-lib-py/compare/v0.0.1...v0.1.0)

> 22 April 2020

- Update to changes of keeper-py-lib 0.2.1 [`72ed632`](https://github.com/nevermined-io/contracts-lib-py/commit/72ed63262fcae2f6d79dcb3c4f74eadfaa0f0c6b)
- Bump version: 0.0.1 → 0.0.2 [`dc98546`](https://github.com/nevermined-io/contracts-lib-py/commit/dc98546b5ff135976c7716f4fb508d1f5dca2dcc)
- Change release python [`fae6a57`](https://github.com/nevermined-io/contracts-lib-py/commit/fae6a572dfd9fb0e05c9c32f05a42814e6ebe55d)

#### v0.0.1

> 21 April 2020

- First commit [`9903290`](https://github.com/nevermined-io/contracts-lib-py/commit/99032903b6152179b6e778d2a379e61b95077447)
- Change version [`d87495c`](https://github.com/nevermined-io/contracts-lib-py/commit/d87495c034d2b7c2f6c804bb088774e9cb6aebcf)
- Try diferent workflow config [`5a6ac5b`](https://github.com/nevermined-io/contracts-lib-py/commit/5a6ac5b4b8ac935e50d578cb646f6b71f8e152bc)
